@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.43';
+our $VERSION = '0.45';
 
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
@@ -33,8 +33,8 @@ has value => (
 {
     my $validator = validation_for(
         params => [
-            charset => { isa => NonEmptyStr, default => 'utf8' },
-            output  => { isa => Streamable },
+            charset => { type => NonEmptyStr, default => 'utf8' },
+            output  => { type => Streamable },
         ],
         named_to_list => 1,
     );
@@ -253,7 +253,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.43
+version 0.45
 
 =head1 SYNOPSIS
 
@@ -304,21 +304,27 @@ This class does the C<Courriel::Role::Streams> role.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
-(or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel> or via email to L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for Courriel can be found at L<https://github.com/houseabsolute/Courriel>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
